# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/tech_profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/tech_profile.proto',
  package='tech_profile',
  syntax='proto3',
  serialized_options=b'\n org.opencord.voltha.tech_profileZ4github.com/opencord/voltha-protos/v4/go/tech_profile',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n voltha_protos/tech_profile.proto\x12\x0ctech_profile\x1a\x1cgoogle/api/annotations.proto\"\xc8\x01\n\x0fSchedulerConfig\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x31\n\radditional_bw\x18\x02 \x01(\x0e\x32\x1a.tech_profile.AdditionalBW\x12\x10\n\x08priority\x18\x03 \x01(\x07\x12\x0e\n\x06weight\x18\x04 \x01(\x07\x12\x34\n\x0csched_policy\x18\x05 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\"\x95\x01\n\x12TrafficShapingInfo\x12\x0b\n\x03\x63ir\x18\x01 \x01(\x07\x12\x0b\n\x03\x63\x62s\x18\x02 \x01(\x07\x12\x0b\n\x03pir\x18\x03 \x01(\x07\x12\x0b\n\x03pbs\x18\x04 \x01(\x07\x12\x0b\n\x03gir\x18\x05 \x01(\x07\x12>\n\nadd_bw_ind\x18\x06 \x01(\x0e\x32*.tech_profile.InferredAdditionBWIndication\"\xdb\x01\n\x10TrafficScheduler\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x10\n\x08\x61lloc_id\x18\x02 \x01(\x07\x12\x30\n\tscheduler\x18\x03 \x01(\x0b\x32\x1d.tech_profile.SchedulerConfig\x12>\n\x14traffic_shaping_info\x18\x04 \x01(\x0b\x32 .tech_profile.TrafficShapingInfo\x12\x17\n\x0ftech_profile_id\x18\x05 \x01(\x07\"\x8d\x01\n\x11TrafficSchedulers\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06uni_id\x18\x04 \x01(\x07\x12\x0f\n\x07port_no\x18\x05 \x01(\x07\x12\x36\n\x0etraffic_scheds\x18\x03 \x03(\x0b\x32\x1e.tech_profile.TrafficScheduler\"+\n\x15TailDropDiscardConfig\x12\x12\n\nqueue_size\x18\x01 \x01(\x07\"Y\n\x10RedDiscardConfig\x12\x15\n\rmin_threshold\x18\x01 \x01(\x07\x12\x15\n\rmax_threshold\x18\x02 \x01(\x07\x12\x17\n\x0fmax_probability\x18\x03 \x01(\x07\"\x9f\x01\n\x11WRedDiscardConfig\x12-\n\x05green\x18\x01 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12.\n\x06yellow\x18\x02 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12+\n\x03red\x18\x03 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\"\x9d\x02\n\rDiscardConfig\x12\x33\n\x0e\x64iscard_policy\x18\x01 \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12G\n\x18tail_drop_discard_config\x18\x02 \x01(\x0b\x32#.tech_profile.TailDropDiscardConfigH\x00\x12<\n\x12red_discard_config\x18\x03 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfigH\x00\x12>\n\x13wred_discard_config\x18\x04 \x01(\x0b\x32\x1f.tech_profile.WRedDiscardConfigH\x00\x42\x10\n\x0e\x64iscard_config\"\xba\x02\n\x0cTrafficQueue\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x10\n\x08pbit_map\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x65s_encryption\x18\x04 \x01(\x08\x12\x34\n\x0csched_policy\x18\x05 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\x12\x10\n\x08priority\x18\x06 \x01(\x07\x12\x0e\n\x06weight\x18\x07 \x01(\x07\x12\x33\n\x0e\x64iscard_policy\x18\x08 \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12\x33\n\x0e\x64iscard_config\x18\t \x01(\x0b\x32\x1b.tech_profile.DiscardConfig\"\x9e\x01\n\rTrafficQueues\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06uni_id\x18\x04 \x01(\x07\x12\x0f\n\x07port_no\x18\x05 \x01(\x07\x12\x32\n\x0etraffic_queues\x18\x06 \x03(\x0b\x32\x1a.tech_profile.TrafficQueue\x12\x17\n\x0ftech_profile_id\x18\x07 \x01(\x07*<\n\tDirection\x12\x0c\n\x08UPSTREAM\x10\x00\x12\x0e\n\nDOWNSTREAM\x10\x01\x12\x11\n\rBIDIRECTIONAL\x10\x02*;\n\x10SchedulingPolicy\x12\x07\n\x03WRR\x10\x00\x12\x12\n\x0eStrictPriority\x10\x01\x12\n\n\x06Hybrid\x10\x02*n\n\x0c\x41\x64\x64itionalBW\x12\x15\n\x11\x41\x64\x64itionalBW_None\x10\x00\x12\x13\n\x0f\x41\x64\x64itionalBW_NA\x10\x01\x12\x1b\n\x17\x41\x64\x64itionalBW_BestEffort\x10\x02\x12\x15\n\x11\x41\x64\x64itionalBW_Auto\x10\x03*?\n\rDiscardPolicy\x12\x0c\n\x08TailDrop\x10\x00\x12\r\n\tWTailDrop\x10\x01\x12\x07\n\x03Red\x10\x02\x12\x08\n\x04WRed\x10\x03*\x9c\x01\n\x1cInferredAdditionBWIndication\x12%\n!InferredAdditionBWIndication_None\x10\x00\x12(\n$InferredAdditionBWIndication_Assured\x10\x01\x12+\n\'InferredAdditionBWIndication_BestEffort\x10\x02\x42X\n org.opencord.voltha.tech_profileZ4github.com/opencord/voltha-protos/v4/go/tech_profileb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='tech_profile.Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPSTREAM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNSTREAM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIDIRECTIONAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1865,
  serialized_end=1925,
)
_sym_db.RegisterEnumDescriptor(_DIRECTION)

Direction = enum_type_wrapper.EnumTypeWrapper(_DIRECTION)
_SCHEDULINGPOLICY = _descriptor.EnumDescriptor(
  name='SchedulingPolicy',
  full_name='tech_profile.SchedulingPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='StrictPriority', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Hybrid', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1927,
  serialized_end=1986,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULINGPOLICY)

SchedulingPolicy = enum_type_wrapper.EnumTypeWrapper(_SCHEDULINGPOLICY)
_ADDITIONALBW = _descriptor.EnumDescriptor(
  name='AdditionalBW',
  full_name='tech_profile.AdditionalBW',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_NA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_BestEffort', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_Auto', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1988,
  serialized_end=2098,
)
_sym_db.RegisterEnumDescriptor(_ADDITIONALBW)

AdditionalBW = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBW)
_DISCARDPOLICY = _descriptor.EnumDescriptor(
  name='DiscardPolicy',
  full_name='tech_profile.DiscardPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TailDrop', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WTailDrop', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Red', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRed', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2100,
  serialized_end=2163,
)
_sym_db.RegisterEnumDescriptor(_DISCARDPOLICY)

DiscardPolicy = enum_type_wrapper.EnumTypeWrapper(_DISCARDPOLICY)
_INFERREDADDITIONBWINDICATION = _descriptor.EnumDescriptor(
  name='InferredAdditionBWIndication',
  full_name='tech_profile.InferredAdditionBWIndication',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_Assured', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_BestEffort', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2166,
  serialized_end=2322,
)
_sym_db.RegisterEnumDescriptor(_INFERREDADDITIONBWINDICATION)

InferredAdditionBWIndication = enum_type_wrapper.EnumTypeWrapper(_INFERREDADDITIONBWINDICATION)
UPSTREAM = 0
DOWNSTREAM = 1
BIDIRECTIONAL = 2
WRR = 0
StrictPriority = 1
Hybrid = 2
AdditionalBW_None = 0
AdditionalBW_NA = 1
AdditionalBW_BestEffort = 2
AdditionalBW_Auto = 3
TailDrop = 0
WTailDrop = 1
Red = 2
WRed = 3
InferredAdditionBWIndication_None = 0
InferredAdditionBWIndication_Assured = 1
InferredAdditionBWIndication_BestEffort = 2



_SCHEDULERCONFIG = _descriptor.Descriptor(
  name='SchedulerConfig',
  full_name='tech_profile.SchedulerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='tech_profile.SchedulerConfig.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_bw', full_name='tech_profile.SchedulerConfig.additional_bw', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='tech_profile.SchedulerConfig.priority', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='tech_profile.SchedulerConfig.weight', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sched_policy', full_name='tech_profile.SchedulerConfig.sched_policy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=281,
)


_TRAFFICSHAPINGINFO = _descriptor.Descriptor(
  name='TrafficShapingInfo',
  full_name='tech_profile.TrafficShapingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cir', full_name='tech_profile.TrafficShapingInfo.cir', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cbs', full_name='tech_profile.TrafficShapingInfo.cbs', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pir', full_name='tech_profile.TrafficShapingInfo.pir', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pbs', full_name='tech_profile.TrafficShapingInfo.pbs', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gir', full_name='tech_profile.TrafficShapingInfo.gir', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_bw_ind', full_name='tech_profile.TrafficShapingInfo.add_bw_ind', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=433,
)


_TRAFFICSCHEDULER = _descriptor.Descriptor(
  name='TrafficScheduler',
  full_name='tech_profile.TrafficScheduler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='tech_profile.TrafficScheduler.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='tech_profile.TrafficScheduler.alloc_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='tech_profile.TrafficScheduler.scheduler', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_shaping_info', full_name='tech_profile.TrafficScheduler.traffic_shaping_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tech_profile_id', full_name='tech_profile.TrafficScheduler.tech_profile_id', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=655,
)


_TRAFFICSCHEDULERS = _descriptor.Descriptor(
  name='TrafficSchedulers',
  full_name='tech_profile.TrafficSchedulers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='tech_profile.TrafficSchedulers.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='tech_profile.TrafficSchedulers.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='tech_profile.TrafficSchedulers.uni_id', index=2,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='tech_profile.TrafficSchedulers.port_no', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_scheds', full_name='tech_profile.TrafficSchedulers.traffic_scheds', index=4,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=799,
)


_TAILDROPDISCARDCONFIG = _descriptor.Descriptor(
  name='TailDropDiscardConfig',
  full_name='tech_profile.TailDropDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_size', full_name='tech_profile.TailDropDiscardConfig.queue_size', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=844,
)


_REDDISCARDCONFIG = _descriptor.Descriptor(
  name='RedDiscardConfig',
  full_name='tech_profile.RedDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_threshold', full_name='tech_profile.RedDiscardConfig.min_threshold', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_threshold', full_name='tech_profile.RedDiscardConfig.max_threshold', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_probability', full_name='tech_profile.RedDiscardConfig.max_probability', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=935,
)


_WREDDISCARDCONFIG = _descriptor.Descriptor(
  name='WRedDiscardConfig',
  full_name='tech_profile.WRedDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='green', full_name='tech_profile.WRedDiscardConfig.green', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yellow', full_name='tech_profile.WRedDiscardConfig.yellow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='red', full_name='tech_profile.WRedDiscardConfig.red', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1097,
)


_DISCARDCONFIG = _descriptor.Descriptor(
  name='DiscardConfig',
  full_name='tech_profile.DiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discard_policy', full_name='tech_profile.DiscardConfig.discard_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tail_drop_discard_config', full_name='tech_profile.DiscardConfig.tail_drop_discard_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='red_discard_config', full_name='tech_profile.DiscardConfig.red_discard_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wred_discard_config', full_name='tech_profile.DiscardConfig.wred_discard_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='discard_config', full_name='tech_profile.DiscardConfig.discard_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1100,
  serialized_end=1385,
)


_TRAFFICQUEUE = _descriptor.Descriptor(
  name='TrafficQueue',
  full_name='tech_profile.TrafficQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='tech_profile.TrafficQueue.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='tech_profile.TrafficQueue.gemport_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pbit_map', full_name='tech_profile.TrafficQueue.pbit_map', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aes_encryption', full_name='tech_profile.TrafficQueue.aes_encryption', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sched_policy', full_name='tech_profile.TrafficQueue.sched_policy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='tech_profile.TrafficQueue.priority', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='tech_profile.TrafficQueue.weight', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discard_policy', full_name='tech_profile.TrafficQueue.discard_policy', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discard_config', full_name='tech_profile.TrafficQueue.discard_config', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1388,
  serialized_end=1702,
)


_TRAFFICQUEUES = _descriptor.Descriptor(
  name='TrafficQueues',
  full_name='tech_profile.TrafficQueues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='tech_profile.TrafficQueues.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='tech_profile.TrafficQueues.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='tech_profile.TrafficQueues.uni_id', index=2,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='tech_profile.TrafficQueues.port_no', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_queues', full_name='tech_profile.TrafficQueues.traffic_queues', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tech_profile_id', full_name='tech_profile.TrafficQueues.tech_profile_id', index=5,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1863,
)

_SCHEDULERCONFIG.fields_by_name['direction'].enum_type = _DIRECTION
_SCHEDULERCONFIG.fields_by_name['additional_bw'].enum_type = _ADDITIONALBW
_SCHEDULERCONFIG.fields_by_name['sched_policy'].enum_type = _SCHEDULINGPOLICY
_TRAFFICSHAPINGINFO.fields_by_name['add_bw_ind'].enum_type = _INFERREDADDITIONBWINDICATION
_TRAFFICSCHEDULER.fields_by_name['direction'].enum_type = _DIRECTION
_TRAFFICSCHEDULER.fields_by_name['scheduler'].message_type = _SCHEDULERCONFIG
_TRAFFICSCHEDULER.fields_by_name['traffic_shaping_info'].message_type = _TRAFFICSHAPINGINFO
_TRAFFICSCHEDULERS.fields_by_name['traffic_scheds'].message_type = _TRAFFICSCHEDULER
_WREDDISCARDCONFIG.fields_by_name['green'].message_type = _REDDISCARDCONFIG
_WREDDISCARDCONFIG.fields_by_name['yellow'].message_type = _REDDISCARDCONFIG
_WREDDISCARDCONFIG.fields_by_name['red'].message_type = _REDDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['discard_policy'].enum_type = _DISCARDPOLICY
_DISCARDCONFIG.fields_by_name['tail_drop_discard_config'].message_type = _TAILDROPDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['red_discard_config'].message_type = _REDDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['wred_discard_config'].message_type = _WREDDISCARDCONFIG
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['tail_drop_discard_config'])
_DISCARDCONFIG.fields_by_name['tail_drop_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['red_discard_config'])
_DISCARDCONFIG.fields_by_name['red_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['wred_discard_config'])
_DISCARDCONFIG.fields_by_name['wred_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
_TRAFFICQUEUE.fields_by_name['direction'].enum_type = _DIRECTION
_TRAFFICQUEUE.fields_by_name['sched_policy'].enum_type = _SCHEDULINGPOLICY
_TRAFFICQUEUE.fields_by_name['discard_policy'].enum_type = _DISCARDPOLICY
_TRAFFICQUEUE.fields_by_name['discard_config'].message_type = _DISCARDCONFIG
_TRAFFICQUEUES.fields_by_name['traffic_queues'].message_type = _TRAFFICQUEUE
DESCRIPTOR.message_types_by_name['SchedulerConfig'] = _SCHEDULERCONFIG
DESCRIPTOR.message_types_by_name['TrafficShapingInfo'] = _TRAFFICSHAPINGINFO
DESCRIPTOR.message_types_by_name['TrafficScheduler'] = _TRAFFICSCHEDULER
DESCRIPTOR.message_types_by_name['TrafficSchedulers'] = _TRAFFICSCHEDULERS
DESCRIPTOR.message_types_by_name['TailDropDiscardConfig'] = _TAILDROPDISCARDCONFIG
DESCRIPTOR.message_types_by_name['RedDiscardConfig'] = _REDDISCARDCONFIG
DESCRIPTOR.message_types_by_name['WRedDiscardConfig'] = _WREDDISCARDCONFIG
DESCRIPTOR.message_types_by_name['DiscardConfig'] = _DISCARDCONFIG
DESCRIPTOR.message_types_by_name['TrafficQueue'] = _TRAFFICQUEUE
DESCRIPTOR.message_types_by_name['TrafficQueues'] = _TRAFFICQUEUES
DESCRIPTOR.enum_types_by_name['Direction'] = _DIRECTION
DESCRIPTOR.enum_types_by_name['SchedulingPolicy'] = _SCHEDULINGPOLICY
DESCRIPTOR.enum_types_by_name['AdditionalBW'] = _ADDITIONALBW
DESCRIPTOR.enum_types_by_name['DiscardPolicy'] = _DISCARDPOLICY
DESCRIPTOR.enum_types_by_name['InferredAdditionBWIndication'] = _INFERREDADDITIONBWINDICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SchedulerConfig = _reflection.GeneratedProtocolMessageType('SchedulerConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULERCONFIG,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.SchedulerConfig)
  })
_sym_db.RegisterMessage(SchedulerConfig)

TrafficShapingInfo = _reflection.GeneratedProtocolMessageType('TrafficShapingInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSHAPINGINFO,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TrafficShapingInfo)
  })
_sym_db.RegisterMessage(TrafficShapingInfo)

TrafficScheduler = _reflection.GeneratedProtocolMessageType('TrafficScheduler', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSCHEDULER,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TrafficScheduler)
  })
_sym_db.RegisterMessage(TrafficScheduler)

TrafficSchedulers = _reflection.GeneratedProtocolMessageType('TrafficSchedulers', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSCHEDULERS,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TrafficSchedulers)
  })
_sym_db.RegisterMessage(TrafficSchedulers)

TailDropDiscardConfig = _reflection.GeneratedProtocolMessageType('TailDropDiscardConfig', (_message.Message,), {
  'DESCRIPTOR' : _TAILDROPDISCARDCONFIG,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TailDropDiscardConfig)
  })
_sym_db.RegisterMessage(TailDropDiscardConfig)

RedDiscardConfig = _reflection.GeneratedProtocolMessageType('RedDiscardConfig', (_message.Message,), {
  'DESCRIPTOR' : _REDDISCARDCONFIG,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.RedDiscardConfig)
  })
_sym_db.RegisterMessage(RedDiscardConfig)

WRedDiscardConfig = _reflection.GeneratedProtocolMessageType('WRedDiscardConfig', (_message.Message,), {
  'DESCRIPTOR' : _WREDDISCARDCONFIG,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.WRedDiscardConfig)
  })
_sym_db.RegisterMessage(WRedDiscardConfig)

DiscardConfig = _reflection.GeneratedProtocolMessageType('DiscardConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISCARDCONFIG,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.DiscardConfig)
  })
_sym_db.RegisterMessage(DiscardConfig)

TrafficQueue = _reflection.GeneratedProtocolMessageType('TrafficQueue', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICQUEUE,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TrafficQueue)
  })
_sym_db.RegisterMessage(TrafficQueue)

TrafficQueues = _reflection.GeneratedProtocolMessageType('TrafficQueues', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICQUEUES,
  '__module__' : 'voltha_protos.tech_profile_pb2'
  # @@protoc_insertion_point(class_scope:tech_profile.TrafficQueues)
  })
_sym_db.RegisterMessage(TrafficQueues)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
